==> libcamera-docs-0.0.3-1-aarch64.pkg.tar.xz: usr/share/doc/libcamera/api-html/search/all_16.js <==
var searchData=
[
  ['v4l2_5fdevice_2eh_0',['v4l2_device.h',['../v4l2__device_8h.html',1,'']]],
  ['v4l2_5fpixelformat_2eh_1',['v4l2_pixelformat.h',['../v4l2__pixelformat_8h.html',1,'']]],
  ['v4l2_5fsubdevice_2eh_2',['v4l2_subdevice.h',['../v4l2__subdevice_8h.html',1,'']]],
  ['v4l2_5fvideodevice_2eh_3',['v4l2_videodevice.h',['../v4l2__videodevice_8h.html',1,'']]],
  ['v4l2buffercache_4',['V4L2BufferCache',['../classlibcamera_1_1V4L2BufferCache.html',1,'libcamera::V4L2BufferCache'],['../classlibcamera_1_1V4L2BufferCache.html#abf2d3fdf1877c5db0ea73a4ccc17ed46',1,'libcamera::V4L2BufferCache::V4L2BufferCache(const std::vector&lt; std::unique_ptr&lt; FrameBuffer &gt; &gt; &amp;buffers)'],['../classlibcamera_1_1V4L2BufferCache.html#a2e85353e7d8aaeb616be5dd642830401',1,'libcamera::V4L2BufferCache::V4L2BufferCache(unsigned int numEntries)']]],
  ['v4l2capability_5',['V4L2Capability',['../structlibcamera_1_1V4L2Capability.html',1,'libcamera']]],
  ['v4l2device_6',['V4L2Device',['../classlibcamera_1_1V4L2Device.html',1,'libcamera::V4L2Device'],['../classlibcamera_1_1V4L2Device.html#af2c3423ffe8a3333ea7c82018b49844d',1,'libcamera::V4L2Device::V4L2Device()']]],
  ['v4l2deviceformat_7',['V4L2DeviceFormat',['../classlibcamera_1_1V4L2DeviceFormat.html',1,'libcamera']]],
  ['v4l2formats_8',['v4l2Formats',['../classlibcamera_1_1PixelFormatInfo.html#a417e6efba30a28758cb7553125b81580',1,'libcamera::PixelFormatInfo']]],
  ['v4l2m2mconverter_9',['V4L2M2MConverter',['../classlibcamera_1_1V4L2M2MConverter.html',1,'libcamera::V4L2M2MConverter'],['../classlibcamera_1_1V4L2M2MConverter.html#a29aeac44dbed3e1c76d4daad84038dac',1,'libcamera::V4L2M2MConverter::V4L2M2MConverter()']]],
  ['v4l2m2mdevice_10',['V4L2M2MDevice',['../classlibcamera_1_1V4L2M2MDevice.html',1,'libcamera::V4L2M2MDevice'],['../classlibcamera_1_1V4L2M2MDevice.html#aada8b048cfaaefb7da7347e101dfff7f',1,'libcamera::V4L2M2MDevice::V4L2M2MDevice()']]],
  ['v4l2pixelformat_11',['V4L2PixelFormat',['../classlibcamera_1_1V4L2PixelFormat.html',1,'libcamera::V4L2PixelFormat'],['../classlibcamera_1_1V4L2PixelFormat.html#ac38e458d9f1afd50a057a96c4d2a8132',1,'libcamera::V4L2PixelFormat::V4L2PixelFormat()'],['../classlibcamera_1_1V4L2PixelFormat.html#a6efc742cb5c93d7ac1c67f87b810b56b',1,'libcamera::V4L2PixelFormat::V4L2PixelFormat(uint32_t fourcc)']]],
  ['v4l2subdevice_12',['V4L2Subdevice',['../classlibcamera_1_1V4L2Subdevice.html',1,'libcamera::V4L2Subdevice'],['../classlibcamera_1_1V4L2Subdevice.html#aded4791bb9d9a977f33417b19590d1af',1,'libcamera::V4L2Subdevice::V4L2Subdevice()'],['../classlibcamera_1_1MediaEntity.html#ab75d46f7f7ee3270b3cffbb0e821c7b0a6225cd504cb3e7475e63ab83fed66a8d',1,'libcamera::MediaEntity::V4L2Subdevice()']]],
  ['v4l2subdevicecapability_13',['V4L2SubdeviceCapability',['../structlibcamera_1_1V4L2SubdeviceCapability.html',1,'libcamera']]],
  ['v4l2subdeviceformat_14',['V4L2SubdeviceFormat',['../structlibcamera_1_1V4L2SubdeviceFormat.html',1,'libcamera']]],
  ['v4l2videodevice_15',['V4L2VideoDevice',['../classlibcamera_1_1V4L2VideoDevice.html',1,'libcamera::V4L2VideoDevice'],['../classlibcamera_1_1V4L2VideoDevice.html#a612aca15d344aa5c59f9f90d4cb09e57',1,'libcamera::V4L2VideoDevice::V4L2VideoDevice(const std::string &amp;deviceNode)'],['../classlibcamera_1_1V4L2VideoDevice.html#a78fd4cc6f5d062c2392715ae72519377',1,'libcamera::V4L2VideoDevice::V4L2VideoDevice(const MediaEntity *entity)'],['../classlibcamera_1_1MediaEntity.html#ab75d46f7f7ee3270b3cffbb0e821c7b0ae388b4d0db571ad8179ff34593372dea',1,'libcamera::MediaEntity::V4L2VideoDevice()']]],
  ['valid_16',['Valid',['../classlibcamera_1_1CameraConfiguration.html#a64163f21db2fe1ce0a6af5a6f6847744a20c0cf44a388a9c75ea71d49b8c968b3',1,'libcamera::CameraConfiguration']]],
  ['valid_5f_17',['valid_',['../classlibcamera_1_1IPAProxy.html#a86bd383fa58aa3ae979791e5e3e51a83',1,'libcamera::IPAProxy']]],
  ['validate_18',['validate',['../classlibcamera_1_1ControlValidator.html#abcdc9ac8a5bb8d5342d2fb7fb1ce51f5',1,'libcamera::ControlValidator::validate()'],['../classlibcamera_1_1CameraControlValidator.html#a71b33785a52fcdb71b31bc2286ea412d',1,'libcamera::CameraControlValidator::validate()'],['../classlibcamera_1_1CameraConfiguration.html#a29f8f263384c6149775b6011c7397093',1,'libcamera::CameraConfiguration::validate()=0']]],
  ['validatecolorspaces_19',['validateColorSpaces',['../classlibcamera_1_1CameraConfiguration.html#a197791527afd705483a0b6236e32c6b7',1,'libcamera::CameraConfiguration']]],
  ['validator_20',['validator',['../classlibcamera_1_1Camera_1_1Private.html#ab3b02eaffac28effb9752c332318062b',1,'libcamera::Camera::Private']]],
  ['values_21',['values',['../classlibcamera_1_1ControlInfo.html#a51aa2edf48c4ee436f5eebbcd2efe960',1,'libcamera::ControlInfo']]],
  ['verify_22',['verify',['../classlibcamera_1_1PubKey.html#a959683b12bed8b7ec178c8b0b72fe6c5',1,'libcamera::PubKey']]],
  ['version_23',['version',['../structlibcamera_1_1ipa__controls__header.html#aafa53c7f9708a2dc7caaca982a100b2c',1,'libcamera::ipa_controls_header::version()'],['../classlibcamera_1_1CameraManager.html#a491b49c074dfc3c55e791b2b63437011',1,'libcamera::CameraManager::version()'],['../classlibcamera_1_1MediaDevice.html#afd096dd0104ddc8737f56cf23e28d8d6',1,'libcamera::MediaDevice::version()']]],
  ['verticalsubsampling_24',['verticalSubSampling',['../structlibcamera_1_1PixelFormatInfo_1_1Plane.html#aa599a1ae77469374e5ca9e53ae7ee2a5',1,'libcamera::PixelFormatInfo::Plane']]],
  ['vflip_25',['VFlip',['../namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571a0b5d83f7ecb707aee4151b6575ca5af7',1,'libcamera']]],
  ['videorecording_26',['VideoRecording',['../namespacelibcamera.html#a295d1f5e7828d95c0b0aabc0a8baac03ae1ff48054403b149f903eb40e16ec86e',1,'libcamera']]],
  ['viewfinder_27',['Viewfinder',['../namespacelibcamera.html#a295d1f5e7828d95c0b0aabc0a8baac03a30b5987e4c03f83a7e1909e4f72eefd4',1,'libcamera']]],
  ['vstep_28',['vStep',['../classlibcamera_1_1SizeRange.html#a48a92bf815783958873a60707daebefe',1,'libcamera::SizeRange']]]
];

==> libcamera-docs-0.2.0-1-aarch64.pkg.tar.xz: usr/share/doc/libcamera/api-html/search/all_16.js <==
var searchData=
[
  ['v4l2_5fdevice_2eh_0',['v4l2_device.h',['../v4l2__device_8h.html',1,'']]],
  ['v4l2_5fpixelformat_2eh_1',['v4l2_pixelformat.h',['../v4l2__pixelformat_8h.html',1,'']]],
  ['v4l2_5fsubdevice_2eh_2',['v4l2_subdevice.h',['../v4l2__subdevice_8h.html',1,'']]],
  ['v4l2_5fvideodevice_2eh_3',['v4l2_videodevice.h',['../v4l2__videodevice_8h.html',1,'']]],
  ['v4l2buffercache_4',['V4L2BufferCache',['../classlibcamera_1_1V4L2BufferCache.html',1,'libcamera::V4L2BufferCache'],['../classlibcamera_1_1V4L2BufferCache.html#a2e85353e7d8aaeb616be5dd642830401',1,'libcamera::V4L2BufferCache::V4L2BufferCache(unsigned int numEntries)'],['../classlibcamera_1_1V4L2BufferCache.html#abf2d3fdf1877c5db0ea73a4ccc17ed46',1,'libcamera::V4L2BufferCache::V4L2BufferCache(const std::vector&lt; std::unique_ptr&lt; FrameBuffer &gt; &gt; &amp;buffers)']]],
  ['v4l2capability_5',['V4L2Capability',['../structlibcamera_1_1V4L2Capability.html',1,'libcamera']]],
  ['v4l2device_6',['V4L2Device',['../classlibcamera_1_1V4L2Device.html',1,'libcamera::V4L2Device'],['../classlibcamera_1_1V4L2Device.html#af2c3423ffe8a3333ea7c82018b49844d',1,'libcamera::V4L2Device::V4L2Device()']]],
  ['v4l2deviceformat_7',['V4L2DeviceFormat',['../classlibcamera_1_1V4L2DeviceFormat.html',1,'libcamera']]],
  ['v4l2formats_8',['v4l2Formats',['../classlibcamera_1_1PixelFormatInfo.html#a417e6efba30a28758cb7553125b81580',1,'libcamera::PixelFormatInfo']]],
  ['v4l2m2mconverter_9',['V4L2M2MConverter',['../classlibcamera_1_1V4L2M2MConverter.html',1,'libcamera::V4L2M2MConverter'],['../classlibcamera_1_1V4L2M2MConverter.html#a29aeac44dbed3e1c76d4daad84038dac',1,'libcamera::V4L2M2MConverter::V4L2M2MConverter()']]],
  ['v4l2m2mdevice_10',['V4L2M2MDevice',['../classlibcamera_1_1V4L2M2MDevice.html',1,'libcamera::V4L2M2MDevice'],['../classlibcamera_1_1V4L2M2MDevice.html#aada8b048cfaaefb7da7347e101dfff7f',1,'libcamera::V4L2M2MDevice::V4L2M2MDevice()']]],
  ['v4l2pixelformat_11',['V4L2PixelFormat',['../classlibcamera_1_1V4L2PixelFormat.html',1,'libcamera::V4L2PixelFormat'],['../classlibcamera_1_1V4L2PixelFormat.html#ac38e458d9f1afd50a057a96c4d2a8132',1,'libcamera::V4L2PixelFormat::V4L2PixelFormat()'],['../classlibcamera_1_1V4L2PixelFormat.html#a6efc742cb5c93d7ac1c67f87b810b56b',1,'libcamera::V4L2PixelFormat::V4L2PixelFormat(uint32_t fourcc)']]],
  ['v4l2subdevice_12',['V4L2Subdevice',['../classlibcamera_1_1V4L2Subdevice.html',1,'libcamera::V4L2Subdevice'],['../classlibcamera_1_1V4L2Subdevice.html#aded4791bb9d9a977f33417b19590d1af',1,'libcamera::V4L2Subdevice::V4L2Subdevice()'],['../classlibcamera_1_1MediaEntity.html#ab75d46f7f7ee3270b3cffbb0e821c7b0a6225cd504cb3e7475e63ab83fed66a8d',1,'libcamera::MediaEntity::V4L2Subdevice']]],
  ['v4l2subdevicecapability_13',['V4L2SubdeviceCapability',['../structlibcamera_1_1V4L2SubdeviceCapability.html',1,'libcamera']]],
  ['v4l2subdeviceformat_14',['V4L2SubdeviceFormat',['../structlibcamera_1_1V4L2SubdeviceFormat.html',1,'libcamera']]],
  ['v4l2videodevice_15',['V4L2VideoDevice',['../classlibcamera_1_1V4L2VideoDevice.html',1,'libcamera::V4L2VideoDevice'],['../classlibcamera_1_1V4L2VideoDevice.html#a612aca15d344aa5c59f9f90d4cb09e57',1,'libcamera::V4L2VideoDevice::V4L2VideoDevice(const std::string &amp;deviceNode)'],['../classlibcamera_1_1V4L2VideoDevice.html#a78fd4cc6f5d062c2392715ae72519377',1,'libcamera::V4L2VideoDevice::V4L2VideoDevice(const MediaEntity *entity)'],['../classlibcamera_1_1MediaEntity.html#ab75d46f7f7ee3270b3cffbb0e821c7b0ae388b4d0db571ad8179ff34593372dea',1,'libcamera::MediaEntity::V4L2VideoDevice']]],
  ['valid_16',['Valid',['../classlibcamera_1_1CameraConfiguration.html#a64163f21db2fe1ce0a6af5a6f6847744a20c0cf44a388a9c75ea71d49b8c968b3',1,'libcamera::CameraConfiguration']]],
  ['valid_5f_17',['valid_',['../classlibcamera_1_1IPAProxy.html#a86bd383fa58aa3ae979791e5e3e51a83',1,'libcamera::IPAProxy']]],
  ['validate_18',['validate',['../classlibcamera_1_1CameraConfiguration.html#a29f8f263384c6149775b6011c7397093',1,'libcamera::CameraConfiguration::validate()'],['../classlibcamera_1_1CameraControlValidator.html#a71b33785a52fcdb71b31bc2286ea412d',1,'libcamera::CameraControlValidator::validate()'],['../classlibcamera_1_1ControlValidator.html#abcdc9ac8a5bb8d5342d2fb7fb1ce51f5',1,'libcamera::ControlValidator::validate()']]],
  ['validatecolorspaces_19',['validateColorSpaces',['../classlibcamera_1_1CameraConfiguration.html#a197791527afd705483a0b6236e32c6b7',1,'libcamera::CameraConfiguration']]],
  ['validator_20',['validator',['../classlibcamera_1_1Camera_1_1Private.html#ab3b02eaffac28effb9752c332318062b',1,'libcamera::Camera::Private']]],
  ['values_21',['values',['../classlibcamera_1_1ControlInfo.html#a51aa2edf48c4ee436f5eebbcd2efe960',1,'libcamera::ControlInfo']]],
  ['verify_22',['verify',['../classlibcamera_1_1PubKey.html#a959683b12bed8b7ec178c8b0b72fe6c5',1,'libcamera::PubKey']]],
  ['version_23',['version',['../structlibcamera_1_1ipa__controls__header.html#aafa53c7f9708a2dc7caaca982a100b2c',1,'libcamera::ipa_controls_header::version'],['../classlibcamera_1_1CameraManager.html#a491b49c074dfc3c55e791b2b63437011',1,'libcamera::CameraManager::version()'],['../classlibcamera_1_1MediaDevice.html#afd096dd0104ddc8737f56cf23e28d8d6',1,'libcamera::MediaDevice::version()']]],
  ['verticalsubsampling_24',['verticalSubSampling',['../structlibcamera_1_1PixelFormatInfo_1_1Plane.html#aa599a1ae77469374e5ca9e53ae7ee2a5',1,'libcamera::PixelFormatInfo::Plane']]],
  ['vflip_25',['VFlip',['../namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571a0b5d83f7ecb707aee4151b6575ca5af7',1,'libcamera']]],
  ['videorecording_26',['VideoRecording',['../namespacelibcamera.html#a295d1f5e7828d95c0b0aabc0a8baac03ae1ff48054403b149f903eb40e16ec86e',1,'libcamera']]],
  ['viewfinder_27',['Viewfinder',['../namespacelibcamera.html#a295d1f5e7828d95c0b0aabc0a8baac03a30b5987e4c03f83a7e1909e4f72eefd4',1,'libcamera']]],
  ['vstep_28',['vStep',['../classlibcamera_1_1SizeRange.html#a48a92bf815783958873a60707daebefe',1,'libcamera::SizeRange']]]
];
